#include "threads/interrupt.h"

/*
 * Terminates Pintos by calling shutdown_power_off()
 * (declared in threads/init.h).
 */
void syscall_halt(struct intr_frame *f);

/*
 * Terminates the current user program, returning status to the kernel. If the
 * process's parent waits for it (see below), this is the status that will be
 * returned. Conventionally, a status of 0 indicates success and nonzero
 * values indicate errors. 
 */
void syscall_exit(struct intr_frame *f);

/*
 * Runs the executable whose name is given in cmd_line, passing any given
 * arguments, and returns the new process's program id (pid). Must return pid
 * -1, which otherwise should not be a valid pid, if the program cannot load or
 * run for any reason. Thus, the parent process cannot return from the exec
 * until it knows whether the child process successfully loaded its executable.
 * You must use appropriate synchronization to ensure this.
 */
void syscall_exec(struct intr_frame *f);

/*
 * Waits for a child process pid and retrieves the child's exit status. 
 */
void syscall_wait(struct intr_frame *f);

/*
 * NOTE: There are more system calls implemented by Pintos but we are not
 * implementing them because the assignment brief does not ask of it.
 */